@@ -2,7 +2,7 @@
 #'
 #' @description Downloads and extracts pdf to text extractor, see details.
 #'
-#' @param dest Destination folder defaults to \code{C:/}
+#' @param dest Destination folder defaults to \code{getwd()}
 #'
 #' @details If function fails you can download the
 #' extractor manually from \url{http://www.foolabs.com/xpdf/}
@@ -15,14 +15,15 @@
 #' @author John Coene \email{jcoenep@@gmail.com}
 #'
 #' @export
-get_xpdf <- function(dest = "C:/"){
+get_xpdf <- function(dest = getwd()){
   os <- Sys.info()['sysname'] # get os
+  checkOS(os, dest)
   lst <- OStoURI(os) # check os
   temp_zip <- tempfile(fileext = lst$ext) # create temp
   download.file(lst$uri, destfile = temp_zip) # download
   unzip(zipfile = temp_zip, exdir = dest) # unzip
   unlink("temp_zip", recursive=TRUE) # delete temp zip once unzipped
-  p <- list.files(paste0(dest, "xpdfbin-win-3.04/bin64/"))
+  p <- list.files(paste0(dest, "/xpdfbin-win-3.04/bin64/"))
   p <- p[grep("pdftotext", p)]
   message("xpdf successfully uzipped, use: \n",
           dest, "xpdfbin-win-3.04/bin64/", p, "\n",
